pitchtools.NumberedChromaticPitchClassColorMap
==============================================

.. autoclass:: abjad.tools.pitchtools.NumberedChromaticPitchClassColorMap
   :members:
   :undoc-members:
   :show-inheritance:
